# telguarder

[![GitHub Release][releases-shield]][releases]
[![Python Versions][py-versions-shield]][py-versions]
![Project Maintenance][maintenance-shield]
[![License][license-shield]][license]
![Made with Love in Norway][madewithlove-shield]

[![Build Status][build-shield]][build]
[![Code coverage][codecov-shield]][codecov]


Asynchronous Python client for the NRK Podcast/Radio API

## Installation

```bash
pip install telguarder
```

## Usage

TBD

## Contributing

If you'd like to contribute to the project, please submit a pull request or open an issue on the GitHub repository.

## License

telguarder is licensed under the MIT license. See the LICENSE file for more details.

## Contact

If you have any questions or need assistance with the library, you can contact the project maintainer at @bendikrb.


[license-shield]: https://img.shields.io/github/license/bendikrb/telguarder.svg
[license]: https://github.com/bendikrb/telguarder/blob/main/LICENSE.md
[releases-shield]: https://img.shields.io/pypi/v/telguarder
[releases]: https://github.com/bendikrb/telguarder/releases
[build-shield]: https://github.com/bendikrb/telguarder/actions/workflows/test.yaml/badge.svg
[build]: https://github.com/bendikrb/telguarder/actions/workflows/test.yaml
[maintenance-shield]: https://img.shields.io/maintenance/yes/2024.svg
[py-versions-shield]: https://img.shields.io/pypi/pyversions/telguarder
[py-versions]: https://pypi.org/project/telguarder/
[codecov-shield]: https://codecov.io/gh/bendikrb/telguarder/graph/badge.svg?token=011O5N9MKL
[codecov]: https://codecov.io/gh/bendikrb/telguarder
[madewithlove-shield]: https://madewithlove.now.sh/no?heart=true&colorB=%233584e4
